@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "verb" "3.1.0"
+(define-package "verb" "20251019.1842"
   "Organize and send HTTP requests."
   '((emacs "26.3"))
   :url "https://github.com/federicotdn/verb"
-  :commit "2e778afd08b8a9872b8273528052f52d53c2bd45"
-  :revdesc "2e778afd08b8"
+  :commit "5f5381333ee5d8ff3df7d1d01b9becc377bb1415"
+  :revdesc "5f5381333ee5"
   :keywords '("tools")
   :authors '(("Federico Tedin" . "federicotedin@gmail.com"))
   :maintainers '(("Federico Tedin" . "federicotedin@gmail.com")))
